@@ -513,6 +513,10 @@ class Document(object):
 class DocumentType(QueryTarget):
     def __init__(self, collection, doc_type):
         super(DocumentType, self).__init__()
+
+        #: The name of the document type
+        self.name = doc_type
+
         self._basepath = collection._basepath + '/type/' + doc_type
         self._resource = collection._resource
 
@@ -533,14 +537,14 @@ class DocumentType(QueryTarget):
         else:
             resp = self._resource.post(path, payload=doc)
 
-        return resp.expect_status(202)
+        return resp.expect_status(202).json
 
     def delete_doc(self, doc_id):
         """Delete a document with this type from the collection.
 
         """
         path = '%s/id/%s' % (self._basepath, doc_id)
-        return self._resource.delete(path).expect_status(202)
+        return self._resource.delete(path).expect_status(202).json
 
     def get_doc(self, doc_id):
         return Document(None, self, doc_id)
@@ -549,6 +553,10 @@ class DocumentType(QueryTarget):
 class Collection(QueryTarget):
     def __init__(self, server, coll_name):
         super(Collection, self).__init__()
+
+        #: The name of the collection
+        self.name = coll_name
+
         self._basepath = '/coll/' + coll_name
         self._resource = server._resource
 
@@ -573,7 +581,7 @@ class Collection(QueryTarget):
     @config.setter
     def config(self, value):
         self._resource.put(self._basepath + '/config', payload=value) \
-            .expect_status(202)
+            .expect_status(202).json
 
     def add_doc(self, doc, doc_type=None, doc_id=None):
         """Add a document to the collection.
@@ -597,14 +605,14 @@ class Collection(QueryTarget):
         else:
             resp = self._resource.post(path, payload=doc)
 
-        return resp.expect_status(202)
+        return resp.expect_status(202).json
 
     def delete_doc(self, doc_type, doc_id):
         """Delete a document from the collection.
 
         """
         path = '%s/type/%s/id/%s' % (self._basepath, doc_type, doc_id)
-        return self._resource.delete(path).expect_status(202)
+        return self._resource.delete(path).expect_status(202).json
 
     def get_doc(self, doc_type, doc_id):
         """Get a document from the collection.
@@ -650,7 +658,7 @@ class Collection(QueryTarget):
         """Delete the entire collection.
 
         """
-        return self._resource.delete(self._basepath).expect_status(202)
+        return self._resource.delete(self._basepath).expect_status(202).json
 
 
 class CheckPoint(object):
@@ -774,6 +782,9 @@ class Taxonomy(object):
 
     """
     def __init__(self, collection, taxonomy_name):
+        #: The name of the taxonomy
+        self.name = taxonomy_name
+
         self._basepath = collection._basepath + '/taxonomy/' + taxonomy_name
         self._resource = collection._resource
 
@@ -788,6 +799,62 @@ class Taxonomy(object):
         """
         return self._resource.get(self._basepath).expect_status(200).json
 
+    def top(self):
+        """Get the top-level category names in the taxonomy.
+
+        This returns a dict representing the categories in the taxonomy which
+        have no parents.  The keys are the category IDs, and the values are
+        objects with the following properties:
+
+         - child_count: The number of direct child categories of this category.
+         - descendant_count: The number of descendants of this category.
+
+        Raises ResourceNotFound if the collection or taxonomy are not found.
+
+        """
+        return self._resource.get(self._basepath + '/top') \
+            .expect_status(200).json
+
+    def get_category(self, category):
+        """Get the details of a category in the taxonomy.
+
+        This returns an object with the following properties:
+
+         - "parents": A list of the category IDs of any direct parents of the
+           category.
+         - "ancestors": A list of the category IDs of any ancestors of the
+           category.
+         - "children": A list of the category IDs of any direct children of the
+           category.
+         - "descendants": A list of the category IDs of any descendants of the
+           category.
+
+        Raises ResourceNotFound if the collection, taxonomy or category are not
+        found.
+
+        """
+        return self._resource.get(self._basepath + '/id/' + category) \
+            .expect_status(200).json
+
+    def add_category(self, category):
+        """Add a category.
+
+        Creates the collection, taxononmy and category if they don't already
+        exist.
+
+        """
+        return self._resource.put(self._basepath + '/id/' + category) \
+            .expect_status(202).json
+
+    def remove_category(self, category):
+        """Remove a category.
+
+        Creates the collection and taxononmy if they don't already exist.
+
+        """
+        return self._resource.delete(self._basepath + '/id/' + category) \
+            .expect_status(202).json
+
     def add_parent(self, category, parent):
         """Add a parent to a category.
 
@@ -807,15 +874,6 @@ class Taxonomy(object):
         return self._resource.delete(self._basepath + '/id/' + category +
                                 '/parent/' + parent).expect_status(202).json
 
-    def remove_category(self, category):
-        """Remove a category.
-
-        Creates the collection and taxononmy if they don't already exist.
-
-        """
-        return self._resource.delete(self._basepath + '/id/' + category) \
-            .expect_status(202).json
-
     def remove(self):
         """Remove this entire taxonomy.
 
